import 'package:flutter/cupertino.dart';
import 'package:image_pickers/image_pickers.dart';
import 'package:get/get.dart';
import 'package:permission_handler/permission_handler.dart';

class PickImageDialog extends StatelessWidget {
  final int maxImageCount;
  final String? photoAlbumText;
  final String? cameraText;
  final String? cancelText;
  final Function(List<Media> pickData)? onFinished;
  final Function? onRequestPermissionFailed;

  PickImageDialog({
    this.maxImageCount = 9,
    this.photoAlbumText,
    this.cameraText,
    this.cancelText,
    this.onFinished,
    this.onRequestPermissionFailed,
  });

  @override
  Widget build(BuildContext context) {
    return CupertinoActionSheet(
      actions: [
        CupertinoActionSheetAction(
          child: Text(
            photoAlbumText ?? 'c_photo_album'.tr,
            style: TextStyle(color: Color(0xFF222222)),
          ),
          onPressed: () async {
            final status = await Permission.photos.request();
            if (status.isGranted || status.isLimited) {
              _onOpenAlbum(context);
            } else {
              if (onRequestPermissionFailed != null) {
                onRequestPermissionFailed!();
              }
            }
          },
        ),
        CupertinoActionSheetAction(
          child: Text(cameraText ?? 'c_camera'.tr, style: TextStyle(color: Color(0xFF222222))),
          onPressed: () async {
            final status = await Permission.camera.request();
            if (status.isGranted || status.isLimited) {
              _onOpenCamera(context);
            } else {
              if (onRequestPermissionFailed != null) {
                onRequestPermissionFailed!();
              }
            }
          },
        ),
      ],
      cancelButton: CupertinoActionSheetAction(
        onPressed: () async {
          Navigator.of(context).pop();
        },
        child: Text(cancelText ?? 'cancel'.tr),
      ),
    );
  }

  // 打开相册
  void _onOpenAlbum(BuildContext context) async {
    List<Media> list = await ImagePickers.pickerPaths(
      galleryMode: GalleryMode.image,
      selectCount: maxImageCount,
      showCamera: false,
      compressSize: 5000,
    );
    Navigator.of(context).pop(list);
    if (onFinished != null) {
      onFinished!(list);
    }
  }

  // 打开相机
  void _onOpenCamera(BuildContext context) async {
    Media? image = await ImagePickers.openCamera();
    List<Media> list = image != null ? [image] : [];
    Navigator.of(context).pop(list);
    if (onFinished != null) {
      onFinished!(list);
    }
  }


}
